Oracle
======

.. automodule:: sqlalchemy.dialects.oracle.base

Oracle Column Types
-------------------

In addition to those types at :ref:`types`, datatypes specific to the
Oracle dialect include those listed here.

.. automodule:: sqlalchemy.dialects.oracle


.. autoclass:: BFILE
  :members: __init__
  :show-inheritance:

.. autoclass:: DOUBLE_PRECISION
   :members: __init__
   :show-inheritance:

.. autoclass:: INTERVAL
  :members: __init__
  :show-inheritance:

.. autoclass:: NCLOB
  :members: __init__
  :show-inheritance:

.. autoclass:: NUMBER
   :members: __init__
   :show-inheritance:

.. autoclass:: LONG
  :members: __init__
  :show-inheritance:

.. autoclass:: RAW
  :members: __init__
  :show-inheritance:

cx_Oracle Notes
---------------

.. automodule:: sqlalchemy.dialects.oracle.cx_oracle

zxjdbc Notes
--------------

.. automodule:: sqlalchemy.dialects.oracle.zxjdbc
